'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var providers_oauth2 = require('./oauth2.js');
require('./base.js');

const defaultConfig = {
  id: "google",
  discoveryDocument: "https://accounts.google.com/.well-known/openid-configuration",
  scope: "openid profile email"
};
class GoogleOAuthProvider extends providers_oauth2.OAuth2Provider {
  constructor(config) {
    super({
      ...defaultConfig,
      ...config
    });
  }
  async getProviderMetadata() {
    const res = await fetch(this.config.discoveryDocument);
    const metadata = await res.json();
    return metadata;
  }
  async getEndpoint(key) {
    const metadata = await this.getProviderMetadata();
    return metadata[key];
  }
  async getSigninUrl({ host }, state) {
    const authorizationEndpoint = await this.getEndpoint("authorization_endpoint");
    const data = {
      response_type: "code",
      client_id: this.config.clientId,
      scope: this.config.scope,
      redirect_uri: this.getCallbackUri(host),
      state,
      login_hint: "example@provider.com",
      nonce: Math.round(Math.random() * 1e3).toString()
    };
    const url = `${authorizationEndpoint}?${new URLSearchParams(data)}`;
    return url;
  }
  async getTokens(code, redirectUri) {
    const tokenEndpoint = await this.getEndpoint("token_endpoint");
    const data = {
      code,
      client_id: this.config.clientId,
      client_secret: this.config.clientSecret,
      redirect_uri: redirectUri,
      grant_type: "authorization_code"
    };
    const res = await fetch(tokenEndpoint, {
      method: "POST",
      headers: {
        "Content-Type": "application/json"
      },
      body: JSON.stringify(data)
    });
    return await res.json();
  }
  async getUserProfile(tokens) {
    const userProfileEndpoint = await this.getEndpoint("userinfo_endpoint");
    const res = await fetch(userProfileEndpoint, {
      headers: { Authorization: `${tokens.token_type} ${tokens.access_token}` }
    });
    return await res.json();
  }
}

exports.GoogleOAuthProvider = GoogleOAuthProvider;
//# sourceMappingURL=google.js.map
