'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var providers_base = require('./base.js');

class OAuth2Provider extends providers_base.Provider {
  async signin(request) {
    const { method, host, query } = request;
    const state = [`redirect=${query.get("redirect") ?? this.getUri(host, "/")}`].join(",");
    const base64State = Buffer.from(state).toString("base64");
    const url = await this.getSigninUrl(request, base64State);
    if (method === "POST") {
      return {
        body: {
          redirect: url
        }
      };
    }
    return {
      status: 302,
      headers: {
        Location: url
      }
    };
  }
  getStateValue(query, name) {
    if (query.get("state")) {
      const state = Buffer.from(query.get("state"), "base64").toString();
      return state.split(",").find((state2) => state2.startsWith(`${name}=`))?.replace(`${name}=`, "");
    }
  }
  async callback({ query, host }) {
    const code = query.get("code");
    const redirect = this.getStateValue(query, "redirect");
    const tokens = await this.getTokens(code, this.getCallbackUri(host));
    let user = await this.getUserProfile(tokens);
    if (this.config.profile) {
      user = await this.config.profile(user, tokens);
    }
    return [user, redirect ?? this.getUri(host, "/")];
  }
}

exports.OAuth2Provider = OAuth2Provider;
//# sourceMappingURL=oauth2.js.map
